diff --git a/MeshLib/IO/XDMF/writeXdmf.cpp b/MeshLib/IO/XDMF/writeXdmf.cpp
index 50742b7124dd07b07e395a455acf13eaf368dfac..ffe7f73db120e1ea2ebc86cc417236adce5ec10e 100644
--- a/MeshLib/IO/XDMF/writeXdmf.cpp
+++ b/MeshLib/IO/XDMF/writeXdmf.cpp
@@ -30,10 +30,10 @@ using namespace BaseLib;
 namespace MeshLib::IO
 {
 // similar definition in Location.h - XDMF uses capital letters
 // Actually there is no correspondece for "IntegrationPoint" in XDMF Format
 // specification
 constexpr char const* mesh_item_type_strings[] = {"Node", "Edge", "Face",
-                                                  "Cell", "IntegrationPoint"};
+                                                  "Cell", "Other"};
 
 // Transforms MeshItemType into string
 static std::string meshItemTypeString(
@@ -30,10 +30,10 @@ using namespace BaseLib;
 {
 // similar definition in Location.h - XDMF uses capital letters
-// Actually there is no correspondece for "IntegrationPoint" in XDMF Format
-// specification
+// There is no correspondece for "IntegrationPoint" in XDMF Format
+// specification - add it as "Other"
 constexpr char const* mesh_item_type_strings[] = {"Node", "Edge", "Face",